@@ -131,6 +131,16 @@ class BaseSnatch:
         logger.info(f"Data received. Status is: {data_obj.integration_status}")
         return data_obj
 
+    def _payload_status(self, max_days_old, max_periods_old, data):
+        payload = {}
+        payload["max_days_old"] = max_days_old
+        payload["max_periods_old"] = max_periods_old
+        payload["data"] = data.__dict__
+        payload["class"] = str(self.__module__).strip("snatch.")
+        if "extends" in self.__dict__:
+            payload["dataset"] = self.extends
+        return payload
+
     def _format_error_response(self, error):
         status_code = (
             error.response.status_code if hasattr(error, "response") else "N/D"
@@ -248,8 +258,6 @@ class BaseSnatch:
         :param period: Specific base date for prospecting.
         :return: DataSource Data Object
         """
-        suffix = []
-        status_validator = {}
         self.tax_id = tax_id
         cnpj = CNPJ()
         cpf = CPF()
@@ -274,16 +282,9 @@ class BaseSnatch:
                 raise ValueError("Invalid Date")
             self.default_period = date
         data = self._last_prospect(timeout=timeout)
-
-        status_validator["max_days_old"] = max_days_old
-        status_validator["max_periods_old"] = max_periods_old
-        status_validator["data"] = data.__dict__
-        status_validator["class"] = str(self.__module__).strip("snatch.")
-        for item in self.extends:
-            suffix.append(item.value)
-        status_validator["dataset"] = suffix
-
-        data.find_current_status(status_validator)
+        data.find_current_status(
+            self._payload_status(max_days_old, max_periods_old, data)
+        )
 
         # Check Status
         if data.integration_status.is_final:
